import { SelectChannelItem } from 'src/types/select-options-item.model';
import { EventEmitter, NgZone, OnDestroy, OnInit } from '@angular/core';
import { FormGroup } from '@angular/forms';
import { HooksService, PluginService, ServerService } from '@app/core';
import { FormReactiveValidationMessages, FormValidatorService } from '@app/shared/shared-forms';
import { InstanceService } from '@app/shared/shared-instance';
import { VideoCaptionEdit, VideoService } from '@app/shared/shared-main';
import { HTMLServerConfig, LiveVideo, RegisterClientFormFieldOptions, RegisterClientVideoFieldOptions, VideoConstant, VideoDetails, VideoPrivacy } from '@shared/models';
import { I18nPrimengCalendarService } from './i18n-primeng-calendar.service';
import { VideoCaptionAddModalComponent } from './video-caption-add-modal.component';
import { VideoEditType } from './video-edit.type';
declare type VideoLanguages = VideoConstant<string> & {
    group?: string;
};
declare type PluginField = {
    commonOptions: RegisterClientFormFieldOptions;
    videoFormOptions: RegisterClientVideoFieldOptions;
};
export declare class VideoEditComponent implements OnInit, OnDestroy {
    private formValidatorService;
    private videoService;
    private serverService;
    private pluginService;
    private instanceService;
    private i18nPrimengCalendarService;
    private ngZone;
    private hooks;
    form: FormGroup;
    formErrors: {
        [id: string]: string;
    };
    validationMessages: FormReactiveValidationMessages;
    videoToUpdate: VideoDetails;
    userVideoChannels: SelectChannelItem[];
    schedulePublicationPossible: boolean;
    videoCaptions: (VideoCaptionEdit & {
        captionPath?: string;
    })[];
    waitTranscodingEnabled: boolean;
    type: VideoEditType;
    liveVideo: LiveVideo;
    videoCaptionAddModal: VideoCaptionAddModalComponent;
    formBuilt: EventEmitter<void>;
    pluginFieldsAdded: EventEmitter<void>;
    readonly SPECIAL_SCHEDULED_PRIVACY = -1;
    videoPrivacies: VideoConstant<VideoPrivacy>[];
    videoCategories: VideoConstant<number>[];
    videoLicences: VideoConstant<number>[];
    videoLanguages: VideoLanguages[];
    pluginDataFormGroup: FormGroup;
    schedulePublicationEnabled: boolean;
    calendarLocale: any;
    minScheduledDate: Date;
    myYearRange: string;
    calendarTimezone: string;
    calendarDateFormat: string;
    serverConfig: HTMLServerConfig;
    pluginFields: PluginField[];
    private schedulerInterval;
    private firstPatchDone;
    private initialVideoCaptions;
    constructor(formValidatorService: FormValidatorService, videoService: VideoService, serverService: ServerService, pluginService: PluginService, instanceService: InstanceService, i18nPrimengCalendarService: I18nPrimengCalendarService, ngZone: NgZone, hooks: HooksService);
    updateForm(): void;
    ngOnInit(): void;
    ngOnDestroy(): void;
    getExistingCaptions(): string[];
    onCaptionAdded(caption: VideoCaptionEdit): void;
    deleteCaption(caption: VideoCaptionEdit): void;
    openAddCaptionModal(): void;
    isSaveReplayEnabled(): boolean;
    isPermanentLiveEnabled(): boolean;
    isPluginFieldHidden(pluginField: PluginField): boolean;
    private sortVideoCaptions;
    private updatePluginFields;
    private trackPrivacyChange;
    private trackChannelChange;
    private trackLivePermanentFieldChange;
    private updateSupportField;
}
export {};
