import { Observable } from 'rxjs';
import { HttpClient } from '@angular/common/http';
import { NgZone } from '@angular/core';
import { VideoEditType } from '@app/+videos/+video-edit/shared/video-edit.type';
import { AuthService } from '@app/core/auth';
import { Notifier } from '@app/core/notification';
import { MarkdownService } from '@app/core/renderer';
import { RestExtractor } from '@app/core/rest';
import { ServerService } from '@app/core/server/server.service';
import { CustomModalComponent } from '@app/modal/custom-modal.component';
import { PluginsManager } from '@root-helpers/plugins-manager';
import { ClientHook, ClientHookName, PluginClientScope, PluginTranslation, PluginType, RegisterClientFormFieldOptions, RegisterClientSettingsScript, RegisterClientVideoFieldOptions, ServerConfigPlugin } from '@shared/models';
export declare class PluginService implements ClientHook {
    private authService;
    private notifier;
    private markdownRenderer;
    private server;
    private zone;
    private authHttp;
    private restExtractor;
    private localeId;
    private static BASE_PLUGIN_API_URL;
    private static BASE_PLUGIN_URL;
    translationsObservable: Observable<PluginTranslation>;
    customModal: CustomModalComponent;
    private helpers;
    private formFields;
    private settingsScripts;
    private pluginsManager;
    constructor(authService: AuthService, notifier: Notifier, markdownRenderer: MarkdownService, server: ServerService, zone: NgZone, authHttp: HttpClient, restExtractor: RestExtractor, localeId: string);
    initializePlugins(): void;
    initializeCustomModal(customModal: CustomModalComponent): void;
    runHook<T>(hookName: ClientHookName, result?: T, params?: any): Promise<T>;
    ensurePluginsAreLoaded(scope: PluginClientScope): Promise<boolean>;
    reloadLoadedScopes(): Promise<void>;
    getPluginsManager(): PluginsManager;
    addPlugin(plugin: ServerConfigPlugin, isTheme?: boolean): void;
    removePlugin(plugin: ServerConfigPlugin): void;
    nameToNpmName(name: string, type: PluginType): string;
    getRegisteredVideoFormFields(type: VideoEditType): {
        commonOptions: RegisterClientFormFieldOptions;
        videoFormOptions: RegisterClientVideoFieldOptions;
    }[];
    getRegisteredSettingsScript(npmName: string): RegisterClientSettingsScript;
    translateBy(npmName: string, toTranslate: string): string | Promise<string>;
    private onFormFields;
    private onSettingsScripts;
    private buildPeerTubeHelpers;
    private loadTranslations;
}
