import { SortMeta } from 'primeng/api';
import { Observable } from 'rxjs';
import { HttpClient } from '@angular/common/http';
import { AuthService } from '@app/core/auth';
import { ActorImage, ResultList, User as UserServerModel, UserCreate, UserRegister, UserUpdate, UserUpdateMe, UserVideoQuota } from '@shared/models';
import { ServerService } from '../';
import { RestExtractor, RestPagination, RestService } from '../rest';
import { LocalStorageService, SessionStorageService } from '../wrappers/storage.service';
import { User } from './user.model';
export declare class UserService {
    private authHttp;
    private server;
    private authService;
    private restExtractor;
    private restService;
    private localStorageService;
    private sessionStorageService;
    static BASE_USERS_URL: string;
    private userCache;
    private signupInThisSession;
    constructor(authHttp: HttpClient, server: ServerService, authService: AuthService, restExtractor: RestExtractor, restService: RestService, localStorageService: LocalStorageService, sessionStorageService: SessionStorageService);
    hasSignupInThisSession(): boolean;
    changePassword(currentPassword: string, newPassword: string): Observable<boolean>;
    changeEmail(password: string, newEmail: string): Observable<boolean>;
    updateMyProfile(profile: UserUpdateMe): Observable<boolean>;
    updateMyAnonymousProfile(profile: UserUpdateMe): void;
    listenAnonymousUpdate(): Observable<User>;
    deleteMe(): Observable<boolean>;
    changeAvatar(avatarForm: FormData): Observable<{
        avatar: ActorImage;
    }>;
    deleteAvatar(): Observable<boolean>;
    signup(userCreate: UserRegister): Observable<boolean>;
    getMyVideoQuotaUsed(): Observable<UserVideoQuota>;
    askResetPassword(email: string): Observable<boolean>;
    resetPassword(userId: number, verificationString: string, password: string): Observable<boolean>;
    verifyEmail(userId: number, verificationString: string, isPendingEmail: boolean): Observable<boolean>;
    askSendVerifyEmail(email: string): Observable<boolean>;
    autocomplete(search: string): Observable<string[]>;
    getNewUsername(oldDisplayName: string, newDisplayName: string, currentUsername: string): string;
    displayNameToUsername(displayName: string): string;
    addUser(userCreate: UserCreate): Observable<boolean>;
    updateUser(userId: number, userUpdate: UserUpdate): Observable<boolean>;
    updateUsers(users: UserServerModel[], userUpdate: UserUpdate): Observable<Object[]>;
    getUserWithCache(userId: number): Observable<UserServerModel>;
    getUser(userId: number, withStats?: boolean): Observable<UserServerModel>;
    getAnonymousUser(): User;
    getUsers(parameters: {
        pagination: RestPagination;
        sort: SortMeta;
        search?: string;
    }): Observable<ResultList<UserServerModel>>;
    removeUser(usersArg: UserServerModel | UserServerModel[]): Observable<Object[]>;
    banUsers(usersArg: UserServerModel | UserServerModel[], reason?: string): Observable<Object[]>;
    unbanUsers(usersArg: UserServerModel | UserServerModel[]): Observable<Object[]>;
    getAnonymousOrLoggedUser(): Observable<User>;
    private formatUser;
}
