import { AuthUser } from '@app/core';
import { User } from '@app/core/users/user.model';
import { ActorImage, HTMLServerConfig, Video as VideoServerModel, VideoConstant, VideoFile, VideoPrivacy, VideoScheduleUpdate, VideoState, VideoStreamingPlaylist } from '@shared/models';
export declare class Video implements VideoServerModel {
    byVideoChannel: string;
    byAccount: string;
    createdAt: Date;
    updatedAt: Date;
    publishedAt: Date;
    originallyPublishedAt: Date | string;
    category: VideoConstant<number>;
    licence: VideoConstant<number>;
    language: VideoConstant<string>;
    privacy: VideoConstant<VideoPrivacy>;
    description: string;
    duration: number;
    durationLabel: string;
    id: number;
    uuid: string;
    shortUUID: string;
    isLocal: boolean;
    name: string;
    serverHost: string;
    thumbnailPath: string;
    thumbnailUrl: string;
    isLive: boolean;
    previewPath: string;
    previewUrl: string;
    embedPath: string;
    embedUrl: string;
    url: string;
    views: number;
    viewers?: number;
    likes: number;
    dislikes: number;
    nsfw: boolean;
    originInstanceUrl: string;
    originInstanceHost: string;
    waitTranscoding?: boolean;
    state?: VideoConstant<VideoState>;
    scheduledUpdate?: VideoScheduleUpdate;
    blacklisted?: boolean;
    blacklistedReason?: string;
    blockedOwner?: boolean;
    blockedServer?: boolean;
    account: {
        id: number;
        name: string;
        displayName: string;
        url: string;
        host: string;
        avatar?: ActorImage;
    };
    channel: {
        id: number;
        name: string;
        displayName: string;
        url: string;
        host: string;
        avatar?: ActorImage;
    };
    userHistory?: {
        currentTime: number;
    };
    pluginData?: any;
    streamingPlaylists?: VideoStreamingPlaylist[];
    files?: VideoFile[];
    static buildWatchUrl(video: Partial<Pick<Video, 'uuid' | 'shortUUID'>>): string;
    static buildUpdateUrl(video: Pick<Video, 'uuid'>): string;
    constructor(hash: VideoServerModel, translations?: {
        [id: string]: string;
    });
    isVideoNSFWForUser(user: User, serverConfig: HTMLServerConfig): boolean;
    isRemovableBy(user: AuthUser): boolean;
    isBlockableBy(user: AuthUser): boolean;
    isUnblockableBy(user: AuthUser): boolean;
    isUpdatableBy(user: AuthUser): boolean;
    canRemoveFiles(user: AuthUser): boolean;
    canRunTranscoding(user: AuthUser): boolean;
    hasHLS(): boolean;
    hasWebTorrent(): boolean;
    isLiveInfoAvailableBy(user: AuthUser): boolean;
    canBeDuplicatedBy(user: AuthUser): boolean;
    getExactNumberOfViews(): string;
}
