import { SortMeta } from 'primeng/api';
import { Observable } from 'rxjs';
import { HttpClient, HttpParams } from '@angular/common/http';
import { ComponentPaginationLight, RestExtractor, RestService, ServerService } from '@app/core';
import { BooleanBothQuery, FeedFormat, NSFWPolicyType, ResultList, UserVideoRate, Video as VideoServerModel, VideoChannel as VideoChannelServerModel, VideoConstant, VideoFileMetadata, VideoInclude, VideoPrivacy, VideoSortField } from '@shared/models';
import { Account } from '../account/account.model';
import { VideoChannel } from '../video-channel';
import { VideoDetails } from './video-details.model';
import { VideoEdit } from './video-edit.model';
import { Video } from './video.model';
export declare type CommonVideoParams = {
    videoPagination?: ComponentPaginationLight;
    sort: VideoSortField | SortMeta;
    include?: VideoInclude;
    isLocal?: boolean;
    categoryOneOf?: number[];
    languageOneOf?: string[];
    privacyOneOf?: VideoPrivacy[];
    isLive?: boolean;
    skipCount?: boolean;
    nsfwPolicy?: NSFWPolicyType;
    nsfw?: BooleanBothQuery;
};
export declare class VideoService {
    private authHttp;
    private restExtractor;
    private restService;
    private serverService;
    static BASE_VIDEO_URL: string;
    static BASE_FEEDS_URL: string;
    static BASE_SUBSCRIPTION_FEEDS_URL: string;
    constructor(authHttp: HttpClient, restExtractor: RestExtractor, restService: RestService, serverService: ServerService);
    getVideoViewUrl(uuid: string): string;
    getUserWatchingVideoUrl(uuid: string): string;
    getVideo(options: {
        videoId: string;
    }): Observable<VideoDetails>;
    updateVideo(video: VideoEdit): Observable<boolean>;
    uploadVideo(video: FormData): Observable<import("@angular/common/http").HttpEvent<{
        video: {
            id: number;
            uuid: string;
        };
    }>>;
    getMyVideos(options: {
        videoPagination: ComponentPaginationLight;
        sort: VideoSortField;
        userChannels?: VideoChannelServerModel[];
        search?: string;
    }): Observable<ResultList<Video>>;
    getAccountVideos(parameters: CommonVideoParams & {
        account: Pick<Account, 'nameWithHost'>;
        search?: string;
    }): Observable<ResultList<Video>>;
    getVideoChannelVideos(parameters: CommonVideoParams & {
        videoChannel: Pick<VideoChannel, 'nameWithHost'>;
    }): Observable<ResultList<Video>>;
    getVideos(parameters: CommonVideoParams): Observable<ResultList<Video>>;
    buildBaseFeedUrls(params: HttpParams, base?: string): {
        format: FeedFormat;
        label: string;
        url: string;
    }[];
    getVideoFeedUrls(sort: VideoSortField, isLocal: boolean, categoryOneOf?: number[]): {
        format: FeedFormat;
        label: string;
        url: string;
    }[];
    getAccountFeedUrls(accountId: number): {
        format: FeedFormat;
        label: string;
        url: string;
    }[];
    getVideoChannelFeedUrls(videoChannelId: number): {
        format: FeedFormat;
        label: string;
        url: string;
    }[];
    getVideoSubscriptionFeedUrls(accountId: number, feedToken: string): {
        format: FeedFormat;
        label: string;
        url: string;
    }[];
    getVideoFileMetadata(metadataUrl: string): Observable<VideoFileMetadata>;
    removeVideo(idArg: number | number[]): Observable<Object[]>;
    removeVideoFiles(videoIds: (number | string)[], type: 'hls' | 'webtorrent'): Observable<Object[]>;
    runTranscoding(videoIds: (number | string)[], type: 'hls' | 'webtorrent'): Observable<Object[]>;
    loadCompleteDescription(descriptionPath: string): Observable<string>;
    setVideoLike(id: number): Observable<boolean>;
    setVideoDislike(id: number): Observable<boolean>;
    unsetVideoLike(id: number): Observable<boolean>;
    getUserVideoRating(id: number): Observable<UserVideoRate>;
    extractVideos(result: ResultList<VideoServerModel>): Observable<{
        total: number;
        data: Video[];
    }>;
    explainedPrivacyLabels(serverPrivacies: VideoConstant<VideoPrivacy>[], defaultPrivacyId?: VideoPrivacy): {
        videoPrivacies: {
            description: string;
            id: VideoPrivacy;
            label: string;
        }[];
        defaultPrivacyId: VideoPrivacy;
    };
    getHighestAvailablePrivacy(serverPrivacies: VideoConstant<VideoPrivacy>[]): VideoPrivacy;
    nsfwPolicyToParam(nsfwPolicy: NSFWPolicyType): "false" | "both";
    buildCommonVideosParams(options: CommonVideoParams & {
        params: HttpParams;
    }): HttpParams;
    private setVideoRate;
}
