import { SortMeta } from 'primeng/api';
import { Observable } from 'rxjs';
import { HttpClient } from '@angular/common/http';
import { ComponentPaginationLight, RestExtractor, RestPagination, RestService } from '@app/core';
import { FeedFormat, ResultList, ThreadsResultList, Video, VideoCommentAdmin, VideoCommentCreate } from '@shared/models';
import { VideoCommentThreadTree } from './video-comment-thread-tree.model';
import { VideoComment } from './video-comment.model';
export declare class VideoCommentService {
    private authHttp;
    private restExtractor;
    private restService;
    static BASE_FEEDS_URL: string;
    private static BASE_VIDEO_URL;
    constructor(authHttp: HttpClient, restExtractor: RestExtractor, restService: RestService);
    addCommentThread(videoId: number | string, comment: VideoCommentCreate): Observable<VideoComment>;
    addCommentReply(videoId: number | string, inReplyToCommentId: number, comment: VideoCommentCreate): Observable<VideoComment>;
    getAdminVideoComments(options: {
        pagination: RestPagination;
        sort: SortMeta;
        search?: string;
    }): Observable<ResultList<VideoCommentAdmin>>;
    getVideoCommentThreads(parameters: {
        videoId: number | string;
        componentPagination: ComponentPaginationLight;
        sort: string;
    }): Observable<ThreadsResultList<VideoComment>>;
    getVideoThreadComments(parameters: {
        videoId: number | string;
        threadId: number;
    }): Observable<VideoCommentThreadTree>;
    deleteVideoComment(videoId: number | string, commentId: number): Observable<boolean>;
    deleteVideoComments(comments: {
        videoId: number | string;
        commentId: number;
    }[]): Observable<boolean[]>;
    getVideoCommentsFeeds(video: Pick<Video, 'uuid'>): {
        format: FeedFormat;
        label: string;
        url: string;
    }[];
    private extractVideoComment;
    private extractVideoComments;
    private extractVideoCommentTree;
    private buildParamsFromSearch;
}
