import { EventEmitter, OnChanges } from '@angular/core';
import { AuthService, ConfirmService, Notifier, ScreenService } from '@app/core';
import { BlocklistService, VideoBlockComponent, VideoBlockService, VideoReportComponent } from '@app/shared/shared-moderation';
import { NgbDropdown } from '@ng-bootstrap/ng-bootstrap';
import { VideoCaption } from '@shared/models';
import { DropdownAction, DropdownButtonSize, DropdownDirection, RedundancyService, Video, VideoDetails, VideoService } from '../shared-main';
import { LiveStreamInformationComponent } from '../shared-video-live';
import { VideoAddToPlaylistComponent } from '../shared-video-playlist';
import { VideoDownloadComponent } from './video-download.component';
export declare type VideoActionsDisplayType = {
    playlist?: boolean;
    download?: boolean;
    update?: boolean;
    blacklist?: boolean;
    delete?: boolean;
    report?: boolean;
    duplicate?: boolean;
    mute?: boolean;
    liveInfo?: boolean;
    removeFiles?: boolean;
    transcoding?: boolean;
};
export declare class VideoActionsDropdownComponent implements OnChanges {
    private authService;
    private notifier;
    private confirmService;
    private blocklistService;
    private videoBlocklistService;
    private screenService;
    private videoService;
    private redundancyService;
    playlistDropdown: NgbDropdown;
    playlistAdd: VideoAddToPlaylistComponent;
    videoDownloadModal: VideoDownloadComponent;
    videoReportModal: VideoReportComponent;
    videoBlockModal: VideoBlockComponent;
    liveStreamInformationModal: LiveStreamInformationComponent;
    video: Video | VideoDetails;
    videoCaptions: VideoCaption[];
    displayOptions: VideoActionsDisplayType;
    placement: string;
    label: string;
    buttonStyled: boolean;
    buttonSize: DropdownButtonSize;
    buttonDirection: DropdownDirection;
    videoFilesRemoved: EventEmitter<any>;
    videoRemoved: EventEmitter<any>;
    videoUnblocked: EventEmitter<any>;
    videoBlocked: EventEmitter<any>;
    videoAccountMuted: EventEmitter<any>;
    transcodingCreated: EventEmitter<any>;
    modalOpened: EventEmitter<any>;
    videoActions: DropdownAction<{
        video: Video;
    }>[][];
    private loaded;
    constructor(authService: AuthService, notifier: Notifier, confirmService: ConfirmService, blocklistService: BlocklistService, videoBlocklistService: VideoBlockService, screenService: ScreenService, videoService: VideoService, redundancyService: RedundancyService);
    get user(): import("@app/core").AuthUser;
    ngOnChanges(): void;
    isUserLoggedIn(): boolean;
    loadDropdownInformation(): void;
    showDownloadModal(): void;
    showReportModal(): void;
    showBlockModal(): void;
    showLiveInfoModal(video: Video): void;
    isVideoUpdatable(): boolean;
    isVideoRemovable(): boolean;
    isVideoBlockable(): boolean;
    isVideoUnblockable(): boolean;
    isVideoLiveInfoAvailable(): boolean;
    isVideoDownloadable(): boolean;
    canVideoBeDuplicated(): boolean;
    isVideoAccountMutable(): boolean;
    canRemoveVideoFiles(): boolean;
    canRunTranscoding(): boolean;
    unblockVideo(): Promise<void>;
    removeVideo(): Promise<void>;
    duplicateVideo(): void;
    muteVideoAccount(): void;
    removeVideoFiles(video: Video, type: 'hls' | 'webtorrent'): Promise<void>;
    runTranscoding(video: Video, type: 'hls' | 'webtorrent'): void;
    onVideoBlocked(): void;
    getPlaylistDropdownPlacement(): "bottom-right" | "bottom-left bottom-right";
    private buildActions;
}
