import { AttributesOnly } from '@shared/core-utils';
import { BooleanBothQuery, NSFWPolicyType, VideoInclude, VideoPrivacy, VideoSortField } from '@shared/models';
declare type VideoFiltersKeys = {
    [id in keyof AttributesOnly<VideoFilters>]: any;
};
export declare type VideoFilterScope = 'local' | 'federated';
export declare class VideoFilters {
    sort: VideoSortField;
    nsfw: BooleanBothQuery;
    languageOneOf: string[];
    categoryOneOf: number[];
    scope: VideoFilterScope;
    allVideos: boolean;
    live: BooleanBothQuery;
    search: string;
    private defaultValues;
    private activeFilters;
    private defaultNSFWPolicy;
    private onChangeCallbacks;
    private oldFormObjectString;
    private readonly hiddenFields;
    constructor(defaultSort: string, defaultScope: VideoFilterScope, hiddenFields?: string[]);
    onChange(cb: () => void): void;
    triggerChange(): void;
    setDefaultScope(scope: VideoFilterScope): void;
    setDefaultSort(sort: string): void;
    setNSFWPolicy(nsfwPolicy: NSFWPolicyType): void;
    reset(specificKey?: string): void;
    load(obj: Partial<AttributesOnly<VideoFilters>>): void;
    buildActiveFilters(): void;
    getActiveFilters(): {
        key: string;
        canRemove: boolean;
        label: string;
        value?: string;
    }[];
    toFormObject(): VideoFiltersKeys;
    toUrlObject(): {
        [id: string]: any;
    };
    toVideosAPIObject(): {
        sort: VideoSortField;
        nsfw: BooleanBothQuery;
        languageOneOf: string[];
        categoryOneOf: number[];
        search: string;
        isLocal: boolean;
        include: VideoInclude;
        privacyOneOf: VideoPrivacy[];
        isLive: boolean;
    };
    getNSFWDisplayLabel(): string;
    private getNSFWValue;
    private updateDefaultNSFW;
}
export {};
