import { Observable, Subject } from 'rxjs';
import { EventEmitter, OnChanges, OnDestroy, OnInit, SimpleChanges } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { AuthService, ComponentPaginationLight, Notifier, PeerTubeRouterService, ScreenService, User, UserService } from '@app/core';
import { GlobalIconName } from '@app/shared/shared-icons';
import { ResultList, VideoSortField } from '@shared/models';
import { Syndication, Video } from '../shared-main';
import { VideoFilters, VideoFilterScope } from './video-filters.model';
import { MiniatureDisplayOptions } from './video-miniature.component';
export declare type HeaderAction = {
    iconName: GlobalIconName;
    label: string;
    justIcon?: boolean;
    routerLink?: string;
    href?: string;
    click?: (e: Event) => void;
};
export declare class VideosListComponent implements OnInit, OnChanges, OnDestroy {
    private notifier;
    private authService;
    private userService;
    private route;
    private screenService;
    private peertubeRouter;
    getVideosObservableFunction: (pagination: ComponentPaginationLight, filters: VideoFilters) => Observable<ResultList<Video>>;
    getSyndicationItemsFunction: (filters: VideoFilters) => Promise<Syndication[]> | Syndication[];
    baseRouteBuilderFunction: (filters: VideoFilters) => string[];
    title: string;
    titleTooltip: string;
    displayTitle: boolean;
    defaultSort: VideoSortField;
    defaultScope: VideoFilterScope;
    displayFilters: boolean;
    displayModerationBlock: boolean;
    loadUserVideoPreferences: boolean;
    displayAsRow: boolean;
    displayVideoActions: boolean;
    groupByDate: boolean;
    headerActions: HeaderAction[];
    hideScopeFilter: boolean;
    displayOptions: MiniatureDisplayOptions;
    disabled: boolean;
    filtersChanged: EventEmitter<VideoFilters>;
    videos: Video[];
    filters: VideoFilters;
    syndicationItems: Syndication[];
    onDataSubject: Subject<any[]>;
    hasDoneFirstQuery: boolean;
    userMiniature: User;
    private routeSub;
    private userSub;
    private resizeSub;
    private pagination;
    private groupedDateLabels;
    private groupedDates;
    private lastQueryLength;
    constructor(notifier: Notifier, authService: AuthService, userService: UserService, route: ActivatedRoute, screenService: ScreenService, peertubeRouter: PeerTubeRouterService);
    ngOnInit(): void;
    ngOnDestroy(): void;
    ngOnChanges(changes: SimpleChanges): void;
    videoById(_index: number, video: Video): number;
    onNearOfBottom(): void;
    loadMoreVideos(reset?: boolean): void;
    reloadVideos(): void;
    removeVideoFromArray(video: Video): void;
    buildGroupedDateLabels(): void;
    getCurrentGroupedDateLabel(video: Video): string;
    scheduleOnFiltersChanged(customizedByUser: boolean): void;
    onFiltersChanged(customizedByUser: boolean): void;
    protected enableAllFilterIfPossible(): void;
    private calcPageSizes;
    private loadUserSettings;
    private reloadSyndicationItems;
    private updateUrl;
    private hasBeenCustomizedByUser;
    private subscribeToAnonymousUpdate;
    private subscribeToSearchChange;
}
