import { Observable } from 'rxjs';
import { HttpClient } from '@angular/common/http';
import { AuthUser, ComponentPaginationLight, RestExtractor, RestService, ServerService } from '@app/core';
import { Account, VideoChannel } from '@app/shared/shared-main';
import { ResultList, VideoExistInPlaylist, VideoPlaylist as VideoPlaylistServerModel, VideoPlaylistCreate, VideoPlaylistElement as ServerVideoPlaylistElement, VideoPlaylistElementCreate, VideoPlaylistElementUpdate, VideoPlaylistUpdate } from '@shared/models';
import { VideoPlaylistElement } from './video-playlist-element.model';
import { VideoPlaylist } from './video-playlist.model';
export declare type CachedPlaylist = VideoPlaylist | {
    id: number;
    displayName: string;
};
export declare class VideoPlaylistService {
    private authHttp;
    private serverService;
    private restExtractor;
    private restService;
    static BASE_VIDEO_PLAYLIST_URL: string;
    static MY_VIDEO_PLAYLIST_URL: string;
    private videoExistsInPlaylistNotifier;
    private videoExistsInPlaylistCacheSubject;
    private readonly videoExistsInPlaylistObservable;
    private videoExistsObservableCache;
    private videoExistsCache;
    private myAccountPlaylistCache;
    private myAccountPlaylistCacheRunning;
    private myAccountPlaylistCacheSubject;
    constructor(authHttp: HttpClient, serverService: ServerService, restExtractor: RestExtractor, restService: RestService);
    listChannelPlaylists(videoChannel: VideoChannel, componentPagination: ComponentPaginationLight): Observable<ResultList<VideoPlaylist>>;
    listMyPlaylistWithCache(user: AuthUser, search?: string): Observable<ResultList<CachedPlaylist>>;
    listAccountPlaylists(account: Account, componentPagination: ComponentPaginationLight, sort: string, search?: string): Observable<ResultList<VideoPlaylist>>;
    getVideoPlaylist(id: string | number): Observable<VideoPlaylist>;
    createVideoPlaylist(body: VideoPlaylistCreate): Observable<{
        videoPlaylist: {
            id: number;
        };
    }>;
    updateVideoPlaylist(videoPlaylist: VideoPlaylist, body: VideoPlaylistUpdate): Observable<boolean>;
    removeVideoPlaylist(videoPlaylist: VideoPlaylist): Observable<boolean>;
    addVideoInPlaylist(playlistId: number, body: VideoPlaylistElementCreate): Observable<{
        videoPlaylistElement: {
            id: number;
        };
    }>;
    updateVideoOfPlaylist(playlistId: number, playlistElementId: number, body: VideoPlaylistElementUpdate, videoId: number): Observable<boolean>;
    removeVideoFromPlaylist(playlistId: number, playlistElementId: number, videoId?: number): Observable<boolean>;
    reorderPlaylist(playlistId: number, oldPosition: number, newPosition: number): Observable<boolean>;
    getPlaylistVideos(options: {
        videoPlaylistId: number | string;
        componentPagination: ComponentPaginationLight;
    }): Observable<ResultList<VideoPlaylistElement>>;
    listenToMyAccountPlaylistsChange(): Observable<ResultList<CachedPlaylist>>;
    listenToVideoPlaylistChange(videoId: number): Observable<VideoExistInPlaylist[]>;
    runPlaylistCheck(videoId: number): void;
    extractPlaylists(result: ResultList<VideoPlaylistServerModel>): Observable<{
        data: VideoPlaylist[];
        total: number;
    }>;
    extractPlaylist(playlist: VideoPlaylistServerModel): Observable<VideoPlaylist>;
    extractVideoPlaylistElements(result: ResultList<ServerVideoPlaylistElement>): Observable<{
        total: number;
        data: VideoPlaylistElement[];
    }>;
    private doVideosExistInPlaylist;
}
