import 'videojs-hotkeys/videojs.hotkeys';
import 'videojs-dock';
import '@peertube/videojs-contextmenu';
import './upnext/end-card';
import './upnext/upnext-plugin';
import './stats/stats-card';
import './stats/stats-plugin';
import './bezels/bezels-plugin';
import './peertube-plugin';
import './peertube-resolutions-plugin';
import './videojs-components/next-previous-video-button';
import './videojs-components/p2p-info-button';
import './videojs-components/peertube-link-button';
import './videojs-components/peertube-load-progress-bar';
import './videojs-components/resolution-menu-button';
import './videojs-components/resolution-menu-item';
import './videojs-components/settings-dialog';
import './videojs-components/settings-menu-button';
import './videojs-components/settings-menu-item';
import './videojs-components/settings-panel';
import './videojs-components/settings-panel-child';
import './videojs-components/theater-button';
import './playlist/playlist-plugin';
import videojs from 'video.js';
import { PluginsManager } from '@root-helpers/plugins-manager';
import { VideoFile } from '@shared/models';
import { PlaylistPluginOptions, UserWatching, VideoJSCaption } from './peertube-videojs-typings';
export declare type PlayerMode = 'webtorrent' | 'p2p-media-loader';
export declare type WebtorrentOptions = {
    videoFiles: VideoFile[];
};
export declare type P2PMediaLoaderOptions = {
    playlistUrl: string;
    segmentsSha256Url: string;
    trackerAnnounce: string[];
    redundancyBaseUrls: string[];
    videoFiles: VideoFile[];
};
export interface CustomizationOptions {
    startTime: number | string;
    stopTime: number | string;
    controls?: boolean;
    muted?: boolean;
    loop?: boolean;
    subtitle?: string;
    resume?: string;
    peertubeLink: boolean;
}
export interface CommonOptions extends CustomizationOptions {
    playerElement: HTMLVideoElement;
    onPlayerElementChange: (element: HTMLVideoElement) => void;
    autoplay: boolean;
    nextVideo?: () => void;
    hasNextVideo?: () => boolean;
    previousVideo?: () => void;
    hasPreviousVideo?: () => boolean;
    playlist?: PlaylistPluginOptions;
    videoDuration: number;
    enableHotkeys: boolean;
    inactivityTimeout: number;
    poster: string;
    theaterButton: boolean;
    captions: boolean;
    videoViewUrl: string;
    embedUrl: string;
    embedTitle: string;
    isLive: boolean;
    language?: string;
    videoCaptions: VideoJSCaption[];
    videoUUID: string;
    videoShortUUID: string;
    userWatching?: UserWatching;
    serverUrl: string;
}
export declare type PeertubePlayerManagerOptions = {
    common: CommonOptions;
    webtorrent: WebtorrentOptions;
    p2pMediaLoader?: P2PMediaLoaderOptions;
    pluginsManager: PluginsManager;
};
export declare class PeertubePlayerManager {
    private static playerElementClassName;
    private static onPlayerChange;
    private static alreadyPlayed;
    private static pluginsManager;
    static initState(): void;
    static initialize(mode: PlayerMode, options: PeertubePlayerManagerOptions, onPlayerChange: (player: videojs.Player) => void): Promise<unknown>;
    private static maybeFallbackToWebTorrent;
    private static getVideojsOptions;
    private static addP2PMediaLoaderOptions;
    private static getHLSOptions;
    private static addWebTorrentOptions;
    private static getControlBarChildren;
    private static addContextMenu;
    private static addHotkeysOptions;
    private static getAutoPlayValue;
}
export { videojs };
