import { HlsConfig, Level } from 'hls.js';
import videojs from 'video.js';
import { VideoFile, VideoPlaylist, VideoPlaylistElement } from '@shared/models';
import { Html5Hlsjs } from './p2p-media-loader/hls-plugin';
import { P2pMediaLoaderPlugin } from './p2p-media-loader/p2p-media-loader-plugin';
import { RedundancyUrlManager } from './p2p-media-loader/redundancy-url-manager';
import { PlayerMode } from './peertube-player-manager';
import { PeerTubePlugin } from './peertube-plugin';
import { PeerTubeResolutionsPlugin } from './peertube-resolutions-plugin';
import { PlaylistPlugin } from './playlist/playlist-plugin';
import { StatsCardOptions } from './stats/stats-card';
import { StatsForNerdsPlugin } from './stats/stats-plugin';
import { EndCardOptions } from './upnext/end-card';
import { WebTorrentPlugin } from './webtorrent/webtorrent-plugin';
declare module 'video.js' {
    interface VideoJsPlayer {
        srOptions_: HlsjsConfigHandlerOptions;
        theaterEnabled: boolean;
        posterImage: {
            show(): void;
            hide(): void;
        };
        handleTechSeeked_(): void;
        peertube(): PeerTubePlugin;
        webtorrent(): WebTorrentPlugin;
        p2pMediaLoader(): P2pMediaLoaderPlugin;
        peertubeResolutions(): PeerTubeResolutionsPlugin;
        contextmenuUI(options: any): any;
        bezels(): void;
        stats(options?: StatsCardOptions): StatsForNerdsPlugin;
        textTracks(): TextTrackList & {
            tracks_: (TextTrack & {
                id: string;
                label: string;
                src: string;
            })[];
        };
        dock(options: {
            title: string;
            description: string;
        }): void;
        upnext(options: Partial<EndCardOptions>): void;
        playlist(): PlaylistPlugin;
    }
}
export interface VideoJSTechHLS extends videojs.Tech {
    hlsProvider: Html5Hlsjs;
}
export interface HlsjsConfigHandlerOptions {
    hlsjsConfig?: HlsConfig;
    levelLabelHandler?: (level: Level) => string;
}
declare type PeerTubeResolution = {
    id: number;
    height?: number;
    label?: string;
    width?: number;
    bitrate?: number;
    selected: boolean;
    selectCallback: () => void;
};
declare type VideoJSCaption = {
    label: string;
    language: string;
    src: string;
};
declare type UserWatching = {
    url: string;
    authorizationHeader: string;
};
declare type PeerTubePluginOptions = {
    mode: PlayerMode;
    autoplay: boolean;
    videoViewUrl: string;
    videoDuration: number;
    userWatching?: UserWatching;
    subtitle?: string;
    videoCaptions: VideoJSCaption[];
    stopTime: number | string;
    isLive: boolean;
    videoUUID: string;
};
declare type PlaylistPluginOptions = {
    elements: VideoPlaylistElement[];
    playlist: VideoPlaylist;
    getCurrentPosition: () => number;
    onItemClicked: (element: VideoPlaylistElement) => void;
};
declare type NextPreviousVideoButtonOptions = {
    type: 'next' | 'previous';
    handler: () => void;
    isDisabled: () => boolean;
};
declare type PeerTubeLinkButtonOptions = {
    shortUUID: string;
};
declare type WebtorrentPluginOptions = {
    playerElement: HTMLVideoElement;
    autoplay: boolean;
    videoDuration: number;
    videoFiles: VideoFile[];
    startTime: number | string;
};
declare type P2PMediaLoaderPluginOptions = {
    redundancyUrlManager: RedundancyUrlManager;
    type: string;
    src: string;
    startTime: number | string;
};
declare type VideoJSPluginOptions = {
    playlist?: PlaylistPluginOptions;
    peertube: PeerTubePluginOptions;
    webtorrent?: WebtorrentPluginOptions;
    p2pMediaLoader?: P2PMediaLoaderPluginOptions;
};
declare type LoadedQualityData = {
    qualitySwitchCallback: (resolutionId: number, type: 'video') => void;
    qualityData: {
        video: {
            id: number;
            label: string;
            selected: boolean;
        }[];
    };
};
declare type ResolutionUpdateData = {
    auto: boolean;
    resolutionId: number;
    id?: number;
};
declare type AutoResolutionUpdateData = {
    possible: boolean;
};
declare type PlayerNetworkInfo = {
    source: 'webtorrent' | 'p2p-media-loader';
    http: {
        downloadSpeed: number;
        uploadSpeed: number;
        downloaded: number;
        uploaded: number;
    };
    p2p: {
        downloadSpeed: number;
        uploadSpeed: number;
        downloaded: number;
        uploaded: number;
        numPeers: number;
    };
    bandwidthEstimate: number;
};
declare type PlaylistItemOptions = {
    element: VideoPlaylistElement;
    onClicked: () => void;
};
export { PlayerNetworkInfo, PlaylistItemOptions, NextPreviousVideoButtonOptions, ResolutionUpdateData, AutoResolutionUpdateData, PlaylistPluginOptions, VideoJSCaption, UserWatching, PeerTubePluginOptions, WebtorrentPluginOptions, P2PMediaLoaderPluginOptions, PeerTubeResolution, VideoJSPluginOptions, LoadedQualityData, PeerTubeLinkButtonOptions };
