import { RegisterClientHelpers } from 'src/types/register-client-option.model';
import { ClientHookName, ClientScript, HTMLServerConfig, PluginClientScope, PluginType, RegisterClientFormFieldOptions, RegisterClientSettingsScript, RegisterClientVideoFieldOptions, ServerConfigPlugin } from '../../../shared/models';
declare type PluginInfo = {
    plugin: ServerConfigPlugin;
    clientScript: ClientScript;
    pluginType: PluginType;
    isTheme: boolean;
};
declare type PeertubeHelpersFactory = (pluginInfo: PluginInfo) => RegisterClientHelpers;
declare type OnFormFields = (options: RegisterClientFormFieldOptions, videoFormOptions: RegisterClientVideoFieldOptions) => void;
declare type OnSettingsScripts = (pluginInfo: PluginInfo, options: RegisterClientSettingsScript) => void;
declare class PluginsManager {
    private hooks;
    private scopes;
    private loadedScripts;
    private loadedScopes;
    private loadingScopes;
    private pluginsLoaded;
    private readonly peertubeHelpersFactory;
    private readonly onFormFields;
    private readonly onSettingsScripts;
    constructor(options: {
        peertubeHelpersFactory: PeertubeHelpersFactory;
        onFormFields?: OnFormFields;
        onSettingsScripts?: OnSettingsScripts;
    });
    static getPluginPathPrefix(isTheme: boolean): "/themes" | "/plugins";
    loadPluginsList(config: HTMLServerConfig): void;
    runHook<T>(hookName: ClientHookName, result?: T, params?: any): Promise<T>;
    ensurePluginsAreLoaded(scope: PluginClientScope): Promise<boolean>;
    reloadLoadedScopes(): Promise<void>;
    addPlugin(plugin: ServerConfigPlugin, isTheme?: boolean): void;
    removePlugin(plugin: ServerConfigPlugin): void;
    loadPluginsByScope(scope: PluginClientScope, isReload?: boolean): Promise<void>;
    private loadPlugin;
    private sortHooksByPriority;
}
export { PluginsManager, PluginInfo, PeertubeHelpersFactory, OnFormFields, OnSettingsScripts };
